@@ -13,6 +13,7 @@ sub new {
 
     # Initialize attributes
     if ( exists($args->{q[accessor]}) ) { do { package Mite::Miteception; (((do { package Mite::Miteception; defined($args->{q[accessor]}) and do { ref(\$args->{q[accessor]}) eq 'SCALAR' or ref(\(my $val = $args->{q[accessor]})) eq 'SCALAR' } }) && (do { local $_ = $args->{q[accessor]}; length($_) > 0 })) or do { package Mite::Miteception; !defined($args->{q[accessor]}) }) } or require Carp && Carp::croak(q[Type check failed in constructor: accessor should be __ANON__|Undef]); $self->{q[accessor]} = $args->{q[accessor]};  }
+    if ( exists($args->{q[alias]}) ) { do { package Mite::Miteception; (do { package Mite::Miteception; defined($args->{q[alias]}) and do { ref(\$args->{q[alias]}) eq 'SCALAR' or ref(\(my $val = $args->{q[alias]})) eq 'SCALAR' } } or (do { package Mite::Miteception; ref($args->{q[alias]}) eq 'ARRAY' } and do { my $ok = 1; for my $i (@{$args->{q[alias]}}) { ($ok = 0, last) unless do { package Mite::Miteception; defined($i) and do { ref(\$i) eq 'SCALAR' or ref(\(my $val = $i)) eq 'SCALAR' } } }; $ok })) } or require Carp && Carp::croak(q[Type check failed in constructor: alias should be Str|ArrayRef[Str]]); $self->{q[alias]} = $args->{q[alias]};  }
     if ( exists($args->{q[builder]}) ) { do { package Mite::Miteception; (((do { package Mite::Miteception; defined($args->{q[builder]}) and do { ref(\$args->{q[builder]}) eq 'SCALAR' or ref(\(my $val = $args->{q[builder]})) eq 'SCALAR' } }) && (do { local $_ = $args->{q[builder]}; length($_) > 0 })) or do { package Mite::Miteception; ref($args->{q[builder]}) eq 'CODE' } or do { package Mite::Miteception; !defined($args->{q[builder]}) }) } or require Carp && Carp::croak(q[Type check failed in constructor: builder should be __ANON__|CodeRef|Undef]); $self->{q[builder]} = $args->{q[builder]};  }
     if ( exists($args->{q[class]}) ) { (do { package Mite::Miteception; use Scalar::Util (); Scalar::Util::blessed($args->{q[class]}) }) or require Carp && Carp::croak(q[Type check failed in constructor: class should be Object]); $self->{q[class]} = $args->{q[class]};  } require Scalar::Util && Scalar::Util::weaken($self->{q[class]});
     if ( exists($args->{q[clearer]}) ) { do { package Mite::Miteception; (((do { package Mite::Miteception; defined($args->{q[clearer]}) and do { ref(\$args->{q[clearer]}) eq 'SCALAR' or ref(\(my $val = $args->{q[clearer]})) eq 'SCALAR' } }) && (do { local $_ = $args->{q[clearer]}; length($_) > 0 })) or do { package Mite::Miteception; !defined($args->{q[clearer]}) }) } or require Carp && Carp::croak(q[Type check failed in constructor: clearer should be __ANON__|Undef]); $self->{q[clearer]} = $args->{q[clearer]};  }
@@ -35,7 +36,7 @@ sub new {
     if ( exists($args->{q[writer]}) ) { do { package Mite::Miteception; (((do { package Mite::Miteception; defined($args->{q[writer]}) and do { ref(\$args->{q[writer]}) eq 'SCALAR' or ref(\(my $val = $args->{q[writer]})) eq 'SCALAR' } }) && (do { local $_ = $args->{q[writer]}; length($_) > 0 })) or do { package Mite::Miteception; !defined($args->{q[writer]}) }) } or require Carp && Carp::croak(q[Type check failed in constructor: writer should be __ANON__|Undef]); $self->{q[writer]} = $args->{q[writer]};  }
 
     # Enforce strict constructor
-    my @unknown = grep not( do { package Mite::Miteception; (defined and !ref and m{\A(?:(?:accessor|builder|c(?:l(?:ass|earer)|o(?:deref_default_variable|erce))|d(?:efault|ocumentation)|handles|i(?:nit_arg|sa?)|lazy|name|predicate|re(?:ader|quired)|t(?:rigger|ype)|w(?:eak_ref|riter)))\z}) } ), keys %{$args}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));
+    my @unknown = grep not( do { package Mite::Miteception; (defined and !ref and m{\A(?:(?:a(?:ccessor|lias)|builder|c(?:l(?:ass|earer)|o(?:deref_default_variable|erce))|d(?:efault|ocumentation)|handles|i(?:nit_arg|sa?)|lazy|name|predicate|re(?:ader|quired)|t(?:rigger|ype)|w(?:eak_ref|riter)))\z}) } ), keys %{$args}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));
 
     # Call BUILD methods
     unless ( $no_build ) { $_->($self, $args) for @{ $meta->{BUILD} || [] } };
@@ -89,6 +90,12 @@ my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSA
 # Accessors for accessor
 *accessor = sub { @_ > 1 ? do { do { package Mite::Miteception; (((do { package Mite::Miteception; defined($_[1]) and do { ref(\$_[1]) eq 'SCALAR' or ref(\(my $val = $_[1])) eq 'SCALAR' } }) && (do { local $_ = $_[1]; length($_) > 0 })) or (!defined($_[1]))) } or require Carp && Carp::croak(q[Type check failed in accessor: value should be __ANON__|Undef]); $_[0]{q[accessor]} = $_[1]; $_[0]; } : do { ( exists($_[0]{q[accessor]}) ? $_[0]{q[accessor]} : ( $_[0]{q[accessor]} = do { my $default_value = $_[0]->_build_accessor; do { package Mite::Miteception; (((do { package Mite::Miteception; defined($default_value) and do { ref(\$default_value) eq 'SCALAR' or ref(\(my $val = $default_value)) eq 'SCALAR' } }) && (do { local $_ = $default_value; length($_) > 0 })) or (!defined($default_value))) } or do { require Carp; Carp::croak(q[Type check failed in default: accessor should be __ANON__|Undef]) }; $default_value } ) ) } };
 
+# Accessors for alias
+*alias = sub { @_ > 1 ? do { do { package Mite::Miteception; (do { package Mite::Miteception; defined($_[1]) and do { ref(\$_[1]) eq 'SCALAR' or ref(\(my $val = $_[1])) eq 'SCALAR' } } or do { package Mite::Miteception; (ref($_[1]) eq 'ARRAY') and do { my $ok = 1; for my $i (@{$_[1]}) { ($ok = 0, last) unless do { package Mite::Miteception; defined($i) and do { ref(\$i) eq 'SCALAR' or ref(\(my $val = $i)) eq 'SCALAR' } } }; $ok } }) } or require Carp && Carp::croak(q[Type check failed in accessor: value should be Str|ArrayRef[Str]]); $_[0]{q[alias]} = $_[1]; $_[0]; } : ( $_[0]{q[alias]} ) };
+
+# Accessors for alias_is_for
+*alias_is_for = sub { @_ > 1 ? require Carp && Carp::croak("alias_is_for is a read-only attribute of @{[ref $_[0]]}") : ( exists($_[0]{q[alias_is_for]}) ? $_[0]{q[alias_is_for]} : ( $_[0]{q[alias_is_for]} = $_[0]->_build_alias_is_for ) ) };
+
 # Accessors for builder
 if ( $__XS ) {
     Class::XSAccessor->import(
